==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/nl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacy",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Het privacy center laat zien waar je data is opgeslagen en wie er toegang toe heeft, omdat je de data met hen deelt of omdat het administrators zijn.",
    "Add external admin" : "Voeg externe beheerder toe",
    "Your files are not protected by encryption." : "Je bestanden zijn niet versleuteld.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Je bestanden zijn versleuteld met {linkopen}server-side-encryptie ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "De server is beschermd met full-disk-encryptie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Je bestanden zijn versleuteld via {linkopen}server-side-encryption ↗{linkclose}. Daarnaast is deze server beveiligd met full-disk-encryptie.",
    "This server is using full-disk-encryption." : "Deze server maakt gebruik van full-disk-encryptie.",
    "Your data is located in: " : "Je bestanden zijn in:",
    "The admin hasn't selected the location of the server yet." : "De beheerder heeft nog geen locatie van de server opgegeven.",
    "Please select a country" : "Graag een land selecteren",
    "You don't have any shares with individual users." : "Je hebt geen shares met individuele gebruikers",
    "Somaliland" : "Samaliland",
    "United Arab Emirates" : "Verenigde Arabische Emiraten",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Argentina" : "Argentinië",
    "Austria" : "Oostenrijk",
    "Australia" : "Australië",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegowina" : "Bosnië en Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarije",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivië",
    "Brazil" : "Brazilië",
    "Bahamas" : "Bahama's",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Centraal Afrikaanse Republiek",
    "Congo" : "Congo",
    "Switzerland" : "Zwitserland",
    "Cote d'Ivoire" : "Ivoorkust",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Tsjechië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denemarken",
    "Dominican Republic" : "Dominicaanse Republiek",
    "Algeria" : "Algerije",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypte",
    "West Sahara" : "Westelijke Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandeilanden",
    "France" : "Frankrijk",
    "Gabon" : "Gabon",
    "United Kingdom" : "Verenigd Koninkrijk",
    "Georgia" : "Georgië",
    "Ghana" : "Ghana",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Equatoriaal Guinea",
    "Greece" : "Griekenland",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarije",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "IJsland",
    "Italy" : "Italië",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgizië",
    "Cambodia" : "Cambodja",
    "North Korea" : "Noord-Korea",
    "South Korea" : "Zuid-Korea",
    "Kuwait" : "Koeweit",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litouwen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Moldova" : "Moldavië",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonië",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolië",
    "Mauritania" : "Mauretanië",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieuw Caledonië",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorwegen",
    "Nepal" : "Nepal",
    "New Zealand" : "Nieuw Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papoea-Nieuw-Guinea",
    "Philippines" : "Filippijnen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Romania" : "Roemenië",
    "Serbia" : "Servië",
    "Russia" : "Rusland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Salomonseilanden",
    "Sudan" : "Soedan",
    "Sweden" : "Zweden",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenië",
    "Slovakia" : "Slowakije",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Zuid-Soedan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syrië",
    "Swaziland" : "Swaziland",
    "Chad" : "Tsjaad",
    "Fr. S. Antarctic Lands" : "Franse Zuidelijke en Antarctische Gebieden",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Timor-Leste" : "Oost-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisië",
    "Turkey" : "Turkije",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Oekraine",
    "Uganda" : "Oeganda",
    "United States" : "Verenigde Staten van Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oezbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Zuid-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Je Nextcloud account",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Uw gegevens geven weer wie u bent en kunnen snel misbruikt worden. Nextcloud is van mening dat mag beslissen wat er met uw gegevens gebeurt. Nextcloud beveiligt uw rechten zoals vastgelegd in het Gegevensbeheerdocument!",
    "User Data Manifesto 2.0" : "Manifest Gebruikerdata 2.0 (Engels)",
    "Defining basic rights for people to control their own data in the internet age" : "Vastleggen van grondrechten voor mensen om hun eigen data te beheren in het internet tijdperk",
    "Control" : "Controle",
    "over user data access" : "Over toegang tot gebruikersgegevens",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Gegevens die bewust en uitdrukkelijk opgeladen werden door een gebruiker moeten steeds onder de uiteindelijke controle van deze gebruiker liggen. Gebruikers moeten in staat zijn om te beslissen aan wie ze rechtstreekse toegang tot hun gegevens verlenen en met welke toegangsrechten en licenties die toegangen toegekend kunnen worden.",
    "Knowledge" : "Kennis",
    "of how the data is stored" : "van hoe de gegevens zijn opgeslagen",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wanneer de gegevens opgeladen zijn naar een specifieke dienstverlener, dan moeten gebruikers ingelicht worden over de locatie waar deze specifieke dienstverlener de gegevens opslaat, voor welke duurtijd dat is, onder welke juridische authoriteit deze dienstverlener werkt, en welke wetgeving erop van toepassing is.",
    "Freedom" : "Vrijheid",
    "to choose a platform" : "om een platform te kiezen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gebruikers moeten steeds in staat zijn hun gegevens uit een dienst te halen zonder problemen dat ze vasthangen aan een dienstverlener. Open standaarden voor datastructuren en protocollen zijn nodig om dit te kunnen garanderen.",
    "Learn more ↗" : "Meer weten",
    "Where is your data?" : "Waar wordt je data opgeslagen?",
    "Who has access to your data?" : "Wie hebben toegang tot je gegevens?",
    "Administrators" : "Beheerders",
    "People you shared with" : "Mensen waarmee je hebt gedeeld",
    "Privacy policy" : "Privacybeleid",
    "Read the privacy policy." : "Lees het %sprivacy beleid%s nu.",
    "Encryption" : "Versleuteling"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/nl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacy",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Het privacy center laat zien waar je data is opgeslagen en wie er toegang toe heeft, omdat je de data met hen deelt of omdat het administrators zijn.",
    "Remove external admin" : "Verwijder een externe beheerder",
    "Add external admin" : "Voeg externe beheerder toe",
    "Name of external admin" : "Naam van externe beheerder",
    "This server is using full-disk-encryption." : "Deze server maakt gebruik van full-disk-encryptie.",
    "Your files are not protected by encryption." : "Je bestanden zijn niet versleuteld.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Je bestanden zijn versleuteld met {linkopen}server-side-encryptie ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "De server is beschermd met full-disk-encryptie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Je bestanden zijn versleuteld via {linkopen}server-side-encryption ↗{linkclose}. Daarnaast is deze server beveiligd met full-disk-encryptie.",
    "Your data is located in: " : "Je bestanden staan in:",
    "The admin hasn't selected the location of the server yet." : "De beheerder heeft nog geen locatie van de server opgegeven.",
    "Change data location" : "Wijzig de gegevenslocatie",
    "Please select a region" : "Kies een regio",
    "You don't have any shares with individual users." : "Je hebt geen shares met individuele gebruikers",
    "Somaliland" : "Samaliland",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Verenigde Arabische Emiraten",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua en Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentinië",
    "American Samoa" : "Amerikaans Samoa",
    "Austria" : "Oostenrijk",
    "Australia" : "Australië",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegovina" : "Bosnië en Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarije",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivië",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius en Saba",
    "Brazil" : "Brazilië",
    "Bahamas" : "Bahama's",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouveteiland",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocoseilanden",
    "Democratic Republic of the Congo" : "Kongo",
    "Central African Republic" : "Centraal Afrikaanse Republiek",
    "Congo" : "Congo",
    "Switzerland" : "Zwitserland",
    "Cote d'Ivoire" : "Ivoorkust",
    "Cook Islands" : "Cookeilanden",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Kaapverdië",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmaseiland",
    "Cyprus" : "Cyprus",
    "Czech" : "Tsjechië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denemarken",
    "Dominican Republic" : "Dominicaanse Republiek",
    "Algeria" : "Algerije",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypte",
    "West Sahara" : "Westelijke Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falklandeilanden",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Faeröer",
    "France" : "Frankrijk",
    "Gabon" : "Gabon",
    "United Kingdom" : "Verenigd Koninkrijk",
    "Grenada" : "Grenada",
    "Georgia" : "Georgië",
    "French Guiana" : "Frans-Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatoriaal Guinea",
    "Greece" : "Griekenland",
    "South Georgia and the South Sandwich Islands" : "Zuid-Georgia en de Zuidelijke Sandwicheilanden",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard en McDonaldeilanden",
    "Croatia" : "Kroatië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarije",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "Isle of Man" : "Man (eiland)",
    "India" : "India",
    "British Indian Ocean Territory" : "Brits Indische Oceaanterritorium",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "IJsland",
    "Italy" : "Italië",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgizië",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comores" : "Comoren",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "North Korea" : "Noord-Korea",
    "South Korea" : "Zuid-Korea",
    "Kuwait" : "Koeweit",
    "Cayman Islands" : "Kaaimaneilanden",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litouwen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova" : "Moldavië",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "Saint-Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshalleilanden",
    "Macedonia" : "Macedonië",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolië",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Noordelijke Marianen",
    "Mauritania" : "Mauretanië",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediven",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieuw Caledonië",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk {eiland)",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorwegen",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nieuw Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Frans-Polynesië",
    "Papua New Guinea" : "Papoea-Nieuw-Guinea",
    "Philippines" : "Filippijnen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre en Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Roemenië",
    "Serbia" : "Servië",
    "Russia" : "Rusland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Salomonseilanden",
    "Seychelles" : "Seychellen",
    "Sudan" : "Soedan",
    "Sweden" : "Zweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sint-Helena, Ascension en Tristan da Cunha",
    "Slovenia" : "Slovenië",
    "Svalbard and Jan Mayen" : "Spitsbergen en Jan Mayen",
    "Slovakia" : "Slowakije",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Zuid-Soedan",
    "Sao Tome and Principe" : "Sao Tomé en Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "Syrië",
    "Swaziland" : "Swaziland",
    "Turks and Caicos Islands" : "Turks- en Caicoseilanden",
    "Chad" : "Tsjaad",
    "Fr. S. Antarctic Lands" : "Franse Zuidelijke en Antarctische Gebieden",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Oost-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisië",
    "Tonga" : "Tonga",
    "Turkey" : "Turkije",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Oekraine",
    "Uganda" : "Oeganda",
    "United States Minor Outlying Islands" : "Kleine afgelegen eilanden van de Verenigde Staten",
    "United States" : "Verenigde Staten van Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oezbekistan",
    "Holy See" : "Heilige Stoel",
    "Saint Vincent and the Grenadines" : "Saint Vincent en de Grenadines",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Britse Maagdeneilanden",
    "Virgin Islands (U.S.)" : "Amerikaanse Maagdeneilanden",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis en Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Zuid-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Je Nextcloud account",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Je gegevens geven weer wie je bent en kunnen snel misbruikt worden. Nextcloud is van mening dat je zelf mag beslissen wat er met je gegevens gebeurt. Nextcloud beveiligt je rechten zoals vastgelegd in het Gegevensbeheerdocument!",
    "User Data Manifesto 2.0" : "Manifest Gebruikerdata 2.0 (Engels)",
    "Defining basic rights for people to control their own data in the internet age" : "Vastleggen van grondrechten voor mensen om hun eigen data te beheren in het internet tijdperk",
    "Control" : "Controle",
    "over user data access" : "Over toegang tot gebruikersgegevens",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Gegevens die bewust en uitdrukkelijk opgeladen werden door een gebruiker moeten steeds onder de uiteindelijke controle van deze gebruiker liggen. Gebruikers moeten in staat zijn om te beslissen aan wie ze rechtstreekse toegang tot hun gegevens verlenen en met welke toegangsrechten en licenties die toegangen toegekend kunnen worden.",
    "Knowledge" : "Kennis",
    "of how the data is stored" : "van hoe de gegevens zijn opgeslagen",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Wanneer de gegevens opgeladen zijn naar een specifieke dienstverlener, dan moeten gebruikers ingelicht worden over de locatie waar deze specifieke dienstverlener de gegevens opslaat, voor welke duurtijd dat is, onder welke juridische authoriteit deze dienstverlener werkt, en welke wetgeving erop van toepassing is.",
    "Freedom" : "Vrijheid",
    "to choose a platform" : "om een platform te kiezen",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Gebruikers moeten steeds in staat zijn hun gegevens uit een dienst te halen zonder problemen dat ze vasthangen aan een dienstverlener. Open standaarden voor datastructuren en protocollen zijn nodig om dit te kunnen garanderen.",
    "Learn more ↗" : "Meer weten",
    "Where is your data?" : "Waar worden je gegevens opgeslagen?",
    "Who has access to your data?" : "Wie hebben toegang tot je gegevens?",
    "Administrators" : "Beheerders",
    "People you shared with" : "Mensen waarmee je hebt gedeeld",
    "Privacy policy" : "Privacybeleid",
    "Read the privacy policy." : "Lees het %sprivacy beleid%s nu.",
    "Encryption" : "Versleuteling"
},
"nplurals=2; plural=(n != 1);");
